<?php

/// Written by David Smith
/// for CSIRO ATNF (c) 2008
///
/// This class inherits from the SQLDatabase class and changes some of the basic
/// functions for interfacing to the database.



require_once GREEN_ZONE_DIR . 'Utils/SQLDatabase.php';



class OCIDBException extends SQLDBException
{
};

class OCIDB extends SQLDatabase
{
  // PUBLIC
      
  public function __construct()
  {
    parent::__construct();
  }
  
  public function __destruct()
  {
    parent::__destruct();
  }
  
  // PRIVATE
  
  /// Connect to the database using the details given, throw an exception if we
  /// failed.

  protected function prot_Connect( $target_user, $target_password, $target_dsn )
  {
    $conn = oci_connect( $target_user, $target_password, $target_dsn );
    if( $conn !== false )
      $this->link = $conn;
    else
      throw new OCIDBException( 'Failed to connect to OCI database', 'OCIDB::prot_Connect' );
  }
  
  /// Disconnect from the database.
  
  protected function prot_Disconnect()
  {
    oci_close( $this->link );
    $this->link = null;
  }
  
  /// Perform the query given and store the results in $this->last_dataset.

  protected function prot_DoQuery( $sql )
  {
    if( $this->link == null )
      throw new OCIDBException( 'Attempt to perform query without connection', 'OCIDB::prot_DoQuery' );
    
    $query = oci_parse( $this->link, $sql );
    
    $res = oci_execute( $query, OCI_DEFAULT );
    if( $res !== false )
    {
      $this->last_dataset = Array();
      $this->last_dataset_index = 0;
      $this->last_query = $sql;
      while( ( $next_row = oci_fetch_array( $query, OCI_RETURN_NULLS ) ) !== false )
        $this->last_dataset[] = $next_row;
    }
  }
  
  /// Throw an exception, this function isn't implemented for oci yet.There is probably
  /// a function for it, but I haven't looked into it as we won't be inserting anything
  /// into an oci database in this project.

  protected function prot_GetInsertID()
  {
    throw new OCIDBException( 'Not implemented', 'OCIDB::prot_GetInsertID' );
  }
};

?>
